package com.khmer9.wa855main.screen.main

import android.view.View
import android.widget.ImageView
import android.widget.TextView
import androidx.appcompat.widget.LinearLayoutCompat
import com.gdtlib.lib.adapter.BaseListItem
import com.gdtlib.lib.viewholder.BaseListViewHolder
import com.google.android.material.card.MaterialCardView
import com.khmer9.wa855main.R
import com.khmer9.wa855main.config.Config
import com.khmer9.wa855main.extension.btnClick
import com.khmer9.wa855main.extension.setSafeOnClickListener
import com.khmer9.wa855main.remote.ModuleData
import com.khmer9.wa855main.remote.SubModuleData
import com.squareup.picasso.Picasso

class MainModuleViewHolder(itemView: View, private val detailButtonListener: ((String, String, Int, Boolean) -> Unit)? = null) : BaseListViewHolder(itemView) {
    private val picasso = Picasso.get()

    override fun bindView(item: BaseListItem) {
        val imgIcon = itemView.findViewById<ImageView>(R.id.img_icon)
        val tvName = itemView.findViewById<TextView>(R.id.tv_name)
        val itemModule = itemView.findViewById<MaterialCardView>(R.id.item_module)
        val backgroundModule = itemView.findViewById<LinearLayoutCompat>(R.id.background_module)

        if (item is ModuleData) {
            tvName.text = item.name

            try {
                val displayMetrics = itemView.context.resources.displayMetrics
                val pxWidth = displayMetrics.widthPixels
                val pxHeight = displayMetrics.heightPixels
                val dpWidth = pxWidth / displayMetrics.density
                val dpHeight = pxHeight / displayMetrics.density

                // high resolution pixel 14400
                var height = dpHeight * 0.5804f

                //low resolution
                if (pxWidth < 1000) {
                    height = dpHeight * 0.2804f
                }

                imgIcon.layoutParams.height = height.toInt()
                imgIcon.layoutParams.width = height.toInt()

                when (item.name.trim().toLowerCase()) {
                    Config.COCK_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_logo_cock)
                            .placeholder(R.drawable.animal_seven)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.chickenbg)
                    }
                    Config.MACHINE_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_lotto_main)
                            .placeholder(R.drawable.ic_lotto_80)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.lottobg)
                    }
                    Config.KD855_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_card)
                            .placeholder(R.drawable.ic_card)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.bg22)
                    }
                    Config.SNK_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_snk)
                            .placeholder(R.drawable.ic_snk)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.bg11)
                    }

                    else -> {
                        picasso
                            .load(R.drawable.ic_lotto_main)
                            .placeholder(R.drawable.animal_seven)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.lottobg)
                    }
                }
            } catch (e: Exception) {
            }

            itemModule.setSafeOnClickListener {
                it.btnClick().subscribe {
                    detailButtonListener?.invoke(item.id, item.appId, item.numberSub, item.comingSoon)
                }
            }
        } else if (item is SubModuleData) {
            tvName.text = item.name

            val displayMetrics = itemView.context.resources.displayMetrics
            val pxWidth = displayMetrics.widthPixels
            val pxHeight = displayMetrics.heightPixels
            val dpWidth = pxWidth / displayMetrics.density
            val dpHeight = pxHeight / displayMetrics.density

            // high resolution pixel 14400
            var height = dpHeight * 0.5804f

            //low resolution
            if (pxWidth < 1000) {
                height = dpHeight * 0.2804f
            }

            imgIcon.layoutParams.height = height.toInt()
            imgIcon.layoutParams.width = height.toInt()

            try {
                when (item.name.trim().toLowerCase()) {
                    Config.LOTTO_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_lotto_80)
                            .placeholder(R.drawable.ic_lotto_80)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.lottobg)
                    }
                    Config.LOTTO_PLUS_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_lotto_plus)
                            .placeholder(R.drawable.ic_lotto_plus)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.lottobg)
                    }
                    Config.YUKI_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_yuki)
                            .placeholder(R.drawable.ic_yuki)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.yukibg)
                    }
                    Config.APONG_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_apong)
                            .placeholder(R.drawable.ic_apong)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.apongbg)
                    }

                    Config.CARD_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_card)
                            .placeholder(R.drawable.ic_card)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.bg22)
                    }
                    Config.RAT_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_snk)
                            .placeholder(R.drawable.ic_snk)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.bg11)
                    }
                    Config.Klaklouk_APP_NAME.trim().toLowerCase() -> {
                        picasso
                            .load(R.drawable.ic_snk)
                            .placeholder(R.drawable.ic_snk)
                            .into(imgIcon)

                        backgroundModule.setBackgroundResource(R.drawable.bg11)
                    }
                    else -> {
                        picasso
                            .load(item.smallIcon)
                            .placeholder(R.drawable.animal_seven)
                            .into(imgIcon)
                    }
                }
            } catch (e: Exception) {
            }

            itemModule.setSafeOnClickListener {
                it.btnClick().subscribe {
                    detailButtonListener?.invoke(item.id, item.appId, 0, false)
                }
            }
        }
    }
}